@@ -27,6 +27,7 @@ from ._sync.client.autoscaling import (  # noqa: F401
 from ._sync.client.cat import CatClient as CatClient  # noqa: F401
 from ._sync.client.ccr import CcrClient as CcrClient  # noqa: F401
 from ._sync.client.cluster import ClusterClient as ClusterClient  # noqa: F401
+from ._sync.client.connector import ConnectorClient as ConnectorClient  # noqa: F401
 from ._sync.client.dangling_indices import (  # noqa: F401
     DanglingIndicesClient as DanglingIndicesClient,
 )
@@ -46,9 +47,7 @@ from ._sync.client.migration import MigrationClient as MigrationClient  # noqa:
 from ._sync.client.ml import MlClient as MlClient  # noqa: F401
 from ._sync.client.monitoring import MonitoringClient as MonitoringClient  # noqa: F401
 from ._sync.client.nodes import NodesClient as NodesClient  # noqa: F401
-from ._sync.client.query_ruleset import (  # noqa: F401
-    QueryRulesetClient as QueryRulesetClient,
-)
+from ._sync.client.query_rules import QueryRulesClient as QueryRulesClient  # noqa: F401
 from ._sync.client.rollup import RollupClient as RollupClient  # noqa: F401
 from ._sync.client.search_application import (  # noqa: F401
     SearchApplicationClient as SearchApplicationClient,
@@ -58,6 +57,7 @@ from ._sync.client.searchable_snapshots import (  # noqa: F401
 )
 from ._sync.client.security import SecurityClient as SecurityClient  # noqa: F401
 from ._sync.client.shutdown import ShutdownClient as ShutdownClient  # noqa: F401
+from ._sync.client.simulate import SimulateClient as SimulateClient  # noqa: F401
 from ._sync.client.slm import SlmClient as SlmClient  # noqa: F401
 from ._sync.client.snapshot import SnapshotClient as SnapshotClient  # noqa: F401
 from ._sync.client.sql import SqlClient as SqlClient  # noqa: F401
@@ -86,6 +86,7 @@ __all__ = [
     "CatClient",
     "CcrClient",
     "ClusterClient",
+    "ConnectorClient",
     "DanglingIndicesClient",
     "Elasticsearch",
     "EnrichClient",
@@ -107,6 +108,7 @@ __all__ = [
     "SearchableSnapshotsClient",
     "SecurityClient",
     "ShutdownClient",
+    "SimulateClient",
     "SlmClient",
     "SnapshotClient",
     "SqlClient",
